'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
var getAttributeIdentifiers = function getAttributeIdentifiers(options) {
  if (!options || typeof options.attributes === 'undefined') return ['data-test-id', 'data-testid'];

  if (Array.isArray(options.attributes)) {
    if (options.attributes.length === 0) {
      throw new Error('option attributes must be an array with at least one element');
    }

    if (options.attributes.length !== options.attributes.filter(function (attr) {
      return attr && typeof attr === 'string';
    }).length) {
      throw new Error('all items in the option attributes must be non empty strings');
    }

    return options.attributes;
  }

  if (!options.attributes || typeof options.attributes !== 'string') {
    throw new Error('option attributes must be a non empty string or an array with non empty strings');
  }

  return [options.attributes];
};

var RemoveDataTestIds = function RemoveDataTestIds(_ref) {
  var t = _ref.types;

  var visitor = {
    JSXOpeningElement: function JSXOpeningElement(path, state) {
      if (path.node.hasStripped) {
        return;
      }

      var attributeIdentifiers = getAttributeIdentifiers(state.opts);

      var validTestIdAttributes = function validTestIdAttributes(attr) {
        var isIdent = attributeIdentifiers.find(function (attribute) {
          return t.isJSXIdentifier(attr.name, { name: attribute });
        });
        return t.isJSXAttribute(attr) && isIdent;
      };

      var replaceClassNameValues = function replaceClassNameValues(attr) {
        var matchingAttrs = function matchingAttrs(currentAttr) {
          if (attr !== currentAttr) {
            return currentAttr;
          }
        };

        var isDefined = function isDefined(value) {
          return typeof value !== 'undefined';
        };

        var attrs = path.node.attributes.map(matchingAttrs).filter(isDefined);

        var node = t.jSXOpeningElement(path.node.name, attrs, path.node.selfClosing);
        node.hasStripped = true;
        path.replaceWith(node);
      };

      path.node.attributes.filter(validTestIdAttributes).forEach(replaceClassNameValues);
    }
  };

  return {
    visitor: visitor
  };
};

exports.default = RemoveDataTestIds;